==> vmngclient-0.11.0-py3-none-any.whl: vmngclient/tests/test_tenant_migration_api.py <==
import tempfile
import unittest
from pathlib import Path
from unittest.mock import MagicMock, patch

from vmngclient.api.task_status_api import Task
from vmngclient.api.tenant_migration_api import ImportTask, TenantMigrationAPI
from vmngclient.model.tenant import Tenant
from vmngclient.primitives.tenant_migration import ImportInfo, MigrationInfo


class TestTenantMigrationAPI(unittest.TestCase):
    @patch("vmngclient.session.vManageSession")
    def setUp(self, session_mock):
        self.session = session_mock
        self.api = TenantMigrationAPI(self.session)

    def test_export_tenant(self):
        tenant = Tenant(desc="Test Tenant", name="test_tenant", subdomain="test_subdomain", org_name="test_org")
        task = self.api.export_tenant(tenant=tenant)
        self.assertIsInstance(task, Task)

    def test_download(self):
        content = b"\xFFtest_data"
        with tempfile.TemporaryDirectory() as tmpdir:
            download_path = Path(tmpdir) / "test.tar.gz"
            self.session.primitives.tenant_migration.download_tenant_data = MagicMock(return_value=content)
            self.api.download(download_path)
            assert open(download_path, "rb").read() == content

    def test_import_tenant(self):
        migration_id = "dcbed267-eb0d-4dcd-9c12-2536e8562f75"
        with tempfile.TemporaryDirectory() as tmpdir:
            import_file = Path(tmpdir) / "tenant.tar.gz"
            with open(import_file, "wb") as f:
                f.write(b"\xFEtest_data")
            self.session.primitives.tenant_migration.import_tenant_data = MagicMock(
                return_value=ImportInfo(
                    processId="123",
                    migrationTokenURL=(
                        "/dataservice/tenantmigration/migrationToken?"
                        "migrationId=dcbed267-eb0d-4dcd-9c12-2536e8562f75"
                    ),
                )
            )
            task = self.api.import_tenant(import_file)
            self.assertIsInstance(task, ImportTask)
            assert task.import_info.migration_token_query_params.migration_id == migration_id

    def test_store_token(self):
        token_data = "test_token1987"
        with tempfile.TemporaryDirectory() as tmpdir:
            download_path = Path(tmpdir) / "token.txt"
            migration_id = "123"
            self.session.primitives.tenant_migration.get_migration_token = MagicMock(return_value=token_data)
            self.api.store_token(migration_id, download_path)
            assert open(download_path, "r").read() == token_data

    def test_migrate_network(self):
        with tempfile.TemporaryDirectory() as tmpdir:
            token_file = Path(tmpdir) / "token_file.txt"
            with open(token_file, "wb") as f:
                f.write(b"token_text")
            self.api.session.primitives.tenant_migration.migrate_network = MagicMock(
                return_value=MigrationInfo(processId="123")
            )
            task = self.api.migrate_network(token_file)
            self.assertIsInstance(task, Task)

==> vmngclient-0.16.0-py3-none-any.whl: vmngclient/tests/test_tenant_migration_api.py <==
import tempfile
import unittest
from pathlib import Path
from unittest.mock import MagicMock, patch

from vmngclient.api.task_status_api import Task
from vmngclient.api.tenant_migration_api import ImportTask, TenantMigrationAPI
from vmngclient.endpoints.tenant_migration import ImportInfo, MigrationInfo
from vmngclient.model.tenant import MigrationTenant, Tenant


class TestTenantMigrationAPI(unittest.TestCase):
    @patch("vmngclient.session.vManageSession")
    def setUp(self, session_mock):
        self.session = session_mock
        self.api = TenantMigrationAPI(self.session)

    def test_export_tenant(self):
        tenant = Tenant(desc="Test Tenant", name="test_tenant", subdomain="test_subdomain", org_name="test_org")
        task = self.api.export_tenant(tenant=tenant)
        self.assertIsInstance(task, Task)

    def test_export_migration_tenant(self):
        tenant = MigrationTenant(
            desc="Test Tenant",
            name="test_tenant",
            subdomain="test_subdomain",
            org_name="test_org",
            is_destination_overlay_mt=False,
        )
        task = self.api.export_tenant(tenant=tenant)
        self.assertIsInstance(task, Task)

    def test_download(self):
        content = b"\xFFtest_data"
        with tempfile.TemporaryDirectory() as tmpdir:
            download_path = Path(tmpdir) / "test.tar.gz"
            self.session.endpoints.tenant_migration.download_tenant_data = MagicMock(return_value=content)
            self.api.download(download_path)
            assert open(download_path, "rb").read() == content

    def test_import_tenant(self):
        migration_id = "dcbed267-eb0d-4dcd-9c12-2536e8562f75"
        with tempfile.TemporaryDirectory() as tmpdir:
            import_file = Path(tmpdir) / "tenant.tar.gz"
            with open(import_file, "wb") as f:
                f.write(b"\xFEtest_data")
            self.session.endpoints.tenant_migration.import_tenant_data = MagicMock(
                return_value=ImportInfo(
                    processId="123",
                    migrationTokenURL=(
                        "/dataservice/tenantmigration/migrationToken?"
                        "migrationId=dcbed267-eb0d-4dcd-9c12-2536e8562f75"
                    ),
                )
            )
            task = self.api.import_tenant(import_file)
            self.assertIsInstance(task, ImportTask)
            assert task.import_info.migration_token_query_params.migration_id == migration_id

    def test_store_token(self):
        token_data = "test_token1987"
        with tempfile.TemporaryDirectory() as tmpdir:
            download_path = Path(tmpdir) / "token.txt"
            migration_id = "123"
            self.session.endpoints.tenant_migration.get_migration_token = MagicMock(return_value=token_data)
            self.api.store_token(migration_id, download_path)
            assert open(download_path, "r").read() == token_data

    def test_migrate_network(self):
        with tempfile.TemporaryDirectory() as tmpdir:
            token_file = Path(tmpdir) / "token_file.txt"
            with open(token_file, "wb") as f:
                f.write(b"token_text")
            self.api.session.endpoints.tenant_migration.migrate_network = MagicMock(
                return_value=MigrationInfo(processId="123")
            )
            task = self.api.migrate_network(token_file)
            self.assertIsInstance(task, Task)
